# graft-templates

This folder contains templates that can be used when creating new grafts.
e.g., 

```bash
quarto-graft graft create calculus --template py-jupyter
```

This will create a new graft called `calculus` under the git branch `graft/calculus`.